@@ -8,7 +8,7 @@
 
 #define MAX_INPUT_CHARS 1024
 
-#define P1FILE DATADIR"/mod_gearman2/mod_gearman_p1.pl"
+#define P1FILE DATADIR"/mod_gearman/mod_gearman_p1.pl"
 
 static PerlInterpreter *my_perl = NULL;
 
@@ -69,8 +69,6 @@ int main(int argc, char **argv) {
 
 int run_epn(char *command_line) {
     SV *plugin_hndlr_cr;
-    STRLEN n_a;
-    int count = 0 ;
     char fname[MAX_INPUT_CHARS];
     char *args[] = {"", "0", "", "", NULL };
     int pclose_result;
@@ -101,7 +99,7 @@ int run_epn(char *command_line) {
 
     PUTBACK;
 
-    count = call_pv("Embed::Persistent::eval_file", G_SCALAR | G_EVAL);
+    call_pv("Embed::Persistent::eval_file", G_SCALAR | G_EVAL);
 
     SPAGAIN;
 
@@ -132,7 +130,7 @@ int run_epn(char *command_line) {
 
     PUTBACK;
 
-    count = perl_call_pv("Embed::Persistent::run_package", G_EVAL | G_ARRAY);
+    perl_call_pv("Embed::Persistent::run_package", G_EVAL | G_ARRAY);
 
     SPAGAIN;
 
